@@ -85,7 +85,6 @@ from typing import (
     TypeVar,
     NamedTuple,
     Tuple,
-    Union,
     Dict,
     Any,
     List,
@@ -409,12 +408,17 @@ def qiita_create_caller(auth_token: str):
 
 
 def qiita_get_item_page(caller: RESTAPI_CALLER_TYPE, page: int, per_page: int):
-    return restapi_json_response(caller(f"{QIITA_API_ENDPOINT}/authenticated_user/items?page={page}&per_page={per_page}", "GET", None))
+    return restapi_json_response(
+        caller(f"{QIITA_API_ENDPOINT}/authenticated_user/items?page={page}&per_page={per_page}", "GET", None))
 
 
 def qiita_get_item_list(caller: RESTAPI_CALLER_TYPE, per_page: int = 10):
-    return reduce(lambda a, b: a + b, filter(None, takewhile(lambda resp: resp is not None and len(resp) != 0,
-        map(lambda page: qiita_get_item_page(caller, page, per_page), count(1)))), [])    
+    return reduce(
+        lambda a, b: a + b,
+        filter(
+            None,
+            takewhile(lambda resp: resp is not None and len(resp) != 0,
+                      map(lambda page: qiita_get_item_page(caller, page, per_page), count(1)))), [])
 
 
 def qiita_get_item(caller: RESTAPI_CALLER_TYPE, id: str):
@@ -874,10 +878,12 @@ def qsync_check_status_local_article(
     if local_article.data.id is None:
         return (SyncStatus.LOCAL_ONLY, None)
     else:
-        global_article = get_global_article(local_article.data.id)
+        global_article = Maybe(get_global_article(
+            local_article.data.id)).map(lambda article: article._replace(filepath=local_article.filepath)).map(
+                qsync.toLocalFormat).get()
         if global_article is None:
             return (SyncStatus.GLOBAL_DELETED, None)
-        elif qsync.toLocalFormat(local_article) == qsync.toLocalFormat(global_article):
+        elif qsync.toLocalFormat(local_article) == global_article:
             return (SyncStatus.SYNC, global_article)
         elif local_article.timestamp > global_article.timestamp:
             return (SyncStatus.LOCAL_NEW, global_article)
@@ -915,7 +921,7 @@ def qsync_str_diff(qsync: QiitaSync, local_article: QiitaArticle, global_article
     return list(
         difflib.unified_diff(
             qsync.toLocalFormat(local_article).body.splitlines(),
-            qsync.toLocalFormat(global_article).body.splitlines()))
+            qsync.toLocalFormat(global_article._replace(filepath=local_article.filepath)).body.splitlines()))
 
 
 def qsync_str_timestamp(article: QiitaArticle) -> str:
@@ -989,7 +995,7 @@ def qsync_do_sync(qsync: QiitaSync, status: SyncStatus, local_article: QiitaArti
 
 
 def qsync_do_purge(qsync: QiitaSync, status: SyncStatus, local_article: QiitaArticle,
-                  global_article: Optional[QiitaArticle]):
+                   global_article: Optional[QiitaArticle]):
     if local_article.data.private:
         qsync.delete(local_article)
         if local_article.filepath is not None:
@@ -1020,7 +1026,6 @@ def qsync_foreach(qsync: QiitaSync, target: Path,
             for article in [QiitaArticle.fromApi(elem) for elem in (qiita_get_item_list(qsync.caller) or [])]
             if article.data.id is not None
         ])
-
         for local_article in qsync.atcl_path_map.values():
             resp = qsync_check_status_local_article(qsync, local_article, lambda id: global_article_dict.get(id))
             handler(qsync, resp[0], local_article, resp[1])
@@ -1070,7 +1075,7 @@ def qsync_argparse() -> ArgumentParser:
     common_arg(subparsers.add_parser("download", help="download help")).set_defaults(func=qsync_subcommand_download)
     common_arg(subparsers.add_parser("upload", help="upload help")).set_defaults(func=qsync_subcommand_upload)
     common_arg(subparsers.add_parser("check", help="check help")).set_defaults(func=qsync_subcommand_check)
-    common_arg(subparsers.add_parser("delete", help="delete help")).set_defaults(func=qsync_subcommand_delete)    
+    common_arg(subparsers.add_parser("delete", help="delete help")).set_defaults(func=qsync_subcommand_delete)
     common_arg(subparsers.add_parser("sync", help="sync help")).set_defaults(func=qsync_subcommand_sync)
     common_arg(subparsers.add_parser("purge", help="purge help")).set_defaults(func=qsync_subcommand_purge)
 
